#!/bin/sh
NODE_ROOT='/usr/NX'

COMMAND_ECHO="/bin/echo"
COMMAND_CAT="/bin/cat"
COMMAND_SU="/bin/su"
COMMAND_RM="/bin/rm"
COMMAND_CHOWN="/bin/chown"

if [ $# -ne 8 ];
  then
    $COMMAND_ECHO "NX> 599 Error: Wrong parameters count." && exit 1
fi

MODE="$3"
COMMAND_XHOST="$4"
USERNAME="$5"
REQ_USERNAME="$6"
DISPLAY="$7"
GLOBALXAUTHORITY="$8"

if [ "x$1" != "xnx" ];
  then
    $COMMAND_ECHO "NX> 599 Error: nxhost.sh only 'nx' user can use xhost by this script" 1>&2
    exit 1
fi

if [ "x$COMMAND_XHOST" = "x" ];
then
 $COMMAND_ECHO "NX> 599 Error: nxhost.sh missing command xhost parameter" 1>&2
 exit 1
fi

checkPpid() {

  if [ "x$1" = "x" ];
  then
    $COMMAND_ECHO "Missing pid"
    return 1
  fi
  if [ ! -e /proc/$1/cmdline ];
  then
    $COMMAND_ECHO "Wrong pid: $1"
    return 1
  fi

  command=$($COMMAND_CAT /proc/$1/cmdline)

  $COMMAND_ECHO "$command"
}

command=$(checkPpid $2)

if [ $? != 0 ];
then
  $COMMAND_ECHO "NX> 500 Error: $command"
  exit 1
fi

if [ "$command" != "nxserver-c$NODE_ROOT/bin/nxserver --login" ];
then
  $COMMAND_ECHO "NX> 500 Error: Only the nxserver can run this script: $command.\n";
  exit 1
fi

if [ "x$MODE" == "xdel" ];
then
  OPERATION="-si";
else
  OPERATION="+si";
fi

if [ ! -x $COMMAND_XHOST ];
then
  $COMMAND_ECHO "NX> 500 Error: Command: $COMMAND_XHOST doesnt exist."
  exit 1
fi

if [ "x$GLOBALXAUTHORITY" != "x" ];
then
  command=`XAUTHORITY=$GLOBALXAUTHORITY DISPLAY=:$DISPLAY $COMMAND_XHOST $OPERATION:localuser:$REQ_USERNAME 2>&1`
  if [ "$?" -ne 0 ];
  then
    $COMMAND_ECHO "NX> 500 Error: Cannot add user: $REQ_USERNAME to the access list: $command"
    exit 1
  else
    command=`XAUTHORITY=$GLOBALXAUTHORITY DISPLAY=:$DISPLAY $COMMAND_XHOST $OPERATION:localuser:nx 2>&1`
    if [ "$?" -eq 0 ];
    then
      $COMMAND_ECHO "xhost success"
    fi
  fi
else
  command=`$COMMAND_SU - $USERNAME -c "DISPLAY=:$DISPLAY $COMMAND_XHOST $OPERATION:localuser:$REQ_USERNAME 2>&1"`
  if [ "$?" -ne 0 ];
  then
    $COMMAND_ECHO "NX> 500 Error: Cannot add user: $REQ_USERNAME to the access list: $command"
    exit 1
  else
    command=`$COMMAND_SU - $USERNAME -c "DISPLAY=:$DISPLAY $COMMAND_XHOST $OPERATION:localuser:nx 2>&1"`
    if [ "$?" -eq 0 ];
    then
      $COMMAND_ECHO "xhost success"
    fi
  fi
fi
